==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/KafkaUserSpecFluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface KafkaUserSpecFluent<A extends KafkaUserSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuthentication instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserAuthentication getAuthentication();
    public KafkaUserAuthentication buildAuthentication();
    public A withAuthentication(KafkaUserAuthentication authentication);
    public Boolean hasAuthentication();
    public A withKafkaUserTlsClientAuthentication(KafkaUserTlsClientAuthentication kafkaUserTlsClientAuthentication);
    public KafkaUserSpecFluent.KafkaUserTlsClientAuthenticationNested<A> withNewKafkaUserTlsClientAuthentication();
    public KafkaUserSpecFluent.KafkaUserTlsClientAuthenticationNested<A> withNewKafkaUserTlsClientAuthenticationLike(KafkaUserTlsClientAuthentication item);
    public A withKafkaUserScramSha512ClientAuthentication(KafkaUserScramSha512ClientAuthentication kafkaUserScramSha512ClientAuthentication);
    public KafkaUserSpecFluent.KafkaUserScramSha512ClientAuthenticationNested<A> withNewKafkaUserScramSha512ClientAuthentication();
    public KafkaUserSpecFluent.KafkaUserScramSha512ClientAuthenticationNested<A> withNewKafkaUserScramSha512ClientAuthenticationLike(KafkaUserScramSha512ClientAuthentication item);
    
/**
 * This method has been deprecated, please use method buildAuthorization instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserAuthorization getAuthorization();
    public KafkaUserAuthorization buildAuthorization();
    public A withAuthorization(KafkaUserAuthorization authorization);
    public Boolean hasAuthorization();
    public A withKafkaUserAuthorizationSimple(KafkaUserAuthorizationSimple kafkaUserAuthorizationSimple);
    public KafkaUserSpecFluent.KafkaUserAuthorizationSimpleNested<A> withNewKafkaUserAuthorizationSimple();
    public KafkaUserSpecFluent.KafkaUserAuthorizationSimpleNested<A> withNewKafkaUserAuthorizationSimpleLike(KafkaUserAuthorizationSimple item);
    
/**
 * This method has been deprecated, please use method buildQuotas instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserQuotas getQuotas();
    public KafkaUserQuotas buildQuotas();
    public A withQuotas(KafkaUserQuotas quotas);
    public Boolean hasQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> withNewQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> withNewQuotasLike(KafkaUserQuotas item);
    public KafkaUserSpecFluent.QuotasNested<A> editQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> editOrNewQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> editOrNewQuotasLike(KafkaUserQuotas item);

    public interface KafkaUserTlsClientAuthenticationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserTlsClientAuthenticationFluent<KafkaUserSpecFluent.KafkaUserTlsClientAuthenticationNested<N>>{

        
    public N and();    public N endKafkaUserTlsClientAuthentication();
}
    public interface KafkaUserScramSha512ClientAuthenticationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserScramSha512ClientAuthenticationFluent<KafkaUserSpecFluent.KafkaUserScramSha512ClientAuthenticationNested<N>>{

        
    public N and();    public N endKafkaUserScramSha512ClientAuthentication();
}
    public interface KafkaUserAuthorizationSimpleNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserAuthorizationSimpleFluent<KafkaUserSpecFluent.KafkaUserAuthorizationSimpleNested<N>>{

        
    public N and();    public N endKafkaUserAuthorizationSimple();
}
    public interface QuotasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserQuotasFluent<KafkaUserSpecFluent.QuotasNested<N>>{

        
    public N and();    public N endQuotas();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/KafkaUserSpecFluent.java <==
package io.strimzi.api.kafka.model;

import io.strimzi.api.kafka.model.template.KafkaUserTemplate;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.template.KafkaUserTemplateBuilder;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.strimzi.api.kafka.model.template.KafkaUserTemplateFluent;

public interface KafkaUserSpecFluent<A extends KafkaUserSpecFluent<A>> extends SpecFluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuthentication instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserAuthentication getAuthentication();
    public KafkaUserAuthentication buildAuthentication();
    public A withAuthentication(KafkaUserAuthentication authentication);
    public Boolean hasAuthentication();
    public A withKafkaUserTlsClientAuthentication(KafkaUserTlsClientAuthentication kafkaUserTlsClientAuthentication);
    public KafkaUserSpecFluent.KafkaUserTlsClientAuthenticationNested<A> withNewKafkaUserTlsClientAuthentication();
    public KafkaUserSpecFluent.KafkaUserTlsClientAuthenticationNested<A> withNewKafkaUserTlsClientAuthenticationLike(KafkaUserTlsClientAuthentication item);
    public A withKafkaUserScramSha512ClientAuthentication(KafkaUserScramSha512ClientAuthentication kafkaUserScramSha512ClientAuthentication);
    public KafkaUserSpecFluent.KafkaUserScramSha512ClientAuthenticationNested<A> withNewKafkaUserScramSha512ClientAuthentication();
    public KafkaUserSpecFluent.KafkaUserScramSha512ClientAuthenticationNested<A> withNewKafkaUserScramSha512ClientAuthenticationLike(KafkaUserScramSha512ClientAuthentication item);
    
/**
 * This method has been deprecated, please use method buildAuthorization instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserAuthorization getAuthorization();
    public KafkaUserAuthorization buildAuthorization();
    public A withAuthorization(KafkaUserAuthorization authorization);
    public Boolean hasAuthorization();
    public A withKafkaUserAuthorizationSimple(KafkaUserAuthorizationSimple kafkaUserAuthorizationSimple);
    public KafkaUserSpecFluent.KafkaUserAuthorizationSimpleNested<A> withNewKafkaUserAuthorizationSimple();
    public KafkaUserSpecFluent.KafkaUserAuthorizationSimpleNested<A> withNewKafkaUserAuthorizationSimpleLike(KafkaUserAuthorizationSimple item);
    
/**
 * This method has been deprecated, please use method buildQuotas instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserQuotas getQuotas();
    public KafkaUserQuotas buildQuotas();
    public A withQuotas(KafkaUserQuotas quotas);
    public Boolean hasQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> withNewQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> withNewQuotasLike(KafkaUserQuotas item);
    public KafkaUserSpecFluent.QuotasNested<A> editQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> editOrNewQuotas();
    public KafkaUserSpecFluent.QuotasNested<A> editOrNewQuotasLike(KafkaUserQuotas item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public KafkaUserTemplate getTemplate();
    public KafkaUserTemplate buildTemplate();
    public A withTemplate(KafkaUserTemplate template);
    public Boolean hasTemplate();
    public KafkaUserSpecFluent.TemplateNested<A> withNewTemplate();
    public KafkaUserSpecFluent.TemplateNested<A> withNewTemplateLike(KafkaUserTemplate item);
    public KafkaUserSpecFluent.TemplateNested<A> editTemplate();
    public KafkaUserSpecFluent.TemplateNested<A> editOrNewTemplate();
    public KafkaUserSpecFluent.TemplateNested<A> editOrNewTemplateLike(KafkaUserTemplate item);

    public interface KafkaUserTlsClientAuthenticationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserTlsClientAuthenticationFluent<KafkaUserSpecFluent.KafkaUserTlsClientAuthenticationNested<N>>{

        
    public N and();    public N endKafkaUserTlsClientAuthentication();
}
    public interface KafkaUserScramSha512ClientAuthenticationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserScramSha512ClientAuthenticationFluent<KafkaUserSpecFluent.KafkaUserScramSha512ClientAuthenticationNested<N>>{

        
    public N and();    public N endKafkaUserScramSha512ClientAuthentication();
}
    public interface KafkaUserAuthorizationSimpleNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserAuthorizationSimpleFluent<KafkaUserSpecFluent.KafkaUserAuthorizationSimpleNested<N>>{

        
    public N and();    public N endKafkaUserAuthorizationSimple();
}
    public interface QuotasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserQuotasFluent<KafkaUserSpecFluent.QuotasNested<N>>{

        
    public N and();    public N endQuotas();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaUserTemplateFluent<KafkaUserSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}
